@@ -265,6 +265,10 @@ spi_init_relation_type_table (AtspiRelationType * types)
   types[ATK_RELATION_DESCRIPTION_FOR] =
     ATSPI_RELATION_DESCRIPTION_FOR;
   types[ATK_RELATION_DESCRIBED_BY] = ATSPI_RELATION_DESCRIBED_BY;
+  types[ATK_RELATION_DETAILS] = ATSPI_RELATION_DETAILS;
+  types[ATK_RELATION_DETAILS_FOR] = ATSPI_RELATION_DETAILS_FOR;
+  types[ATK_RELATION_ERROR_MESSAGE] = ATSPI_RELATION_ERROR_MESSAGE;
+  types[ATK_RELATION_ERROR_FOR] = ATSPI_RELATION_ERROR_FOR;
   types[ATK_RELATION_NODE_PARENT_OF] = ATSPI_RELATION_NODE_PARENT_OF;
 
   return TRUE;
