@@ -451,14 +451,6 @@ adapt_minor_for_dbus (const char *source)
   return ret;
 }
 
-static void
-open_variant (DBusMessageIter *iter, const char *name, const char *type,
-              DBusMessageIter *out)
-{
-  dbus_message_iter_append_basic (iter, DBUS_TYPE_STRING, &name);
-  dbus_message_iter_open_container (iter, DBUS_TYPE_VARIANT, type, out);
-}
-
 /*
  * Emits an AT-SPI event.
  * AT-SPI events names are split into three parts:
@@ -486,7 +478,7 @@ emit_event (AtkObject  *obj,
 
   gchar *cname;
   DBusMessage *sig;
-  DBusMessageIter iter, iter_dict, iter_dict_entry, iter_variant, iter_array;
+  DBusMessageIter iter, iter_dict, iter_dict_entry;
   GArray *properties = NULL;
   
   if (!klass) klass = "";
@@ -952,6 +944,8 @@ text_insert_event_listener (GSignalInvocationHint * signal_hint,
 
   if (G_VALUE_TYPE (&param_values[3]) == G_TYPE_STRING)
     text = g_value_get_string (&param_values[3]);
+  else
+    text = "";
 
   emit_event (accessible, ITF_EVENT_OBJECT, name, minor, detail1, detail2,
               DBUS_TYPE_STRING_AS_STRING, text, append_basic);
@@ -1001,6 +995,8 @@ text_remove_event_listener (GSignalInvocationHint * signal_hint,
 
   if (G_VALUE_TYPE (&param_values[3]) == G_TYPE_STRING)
     text = g_value_get_string (&param_values[3]);
+  else
+    text = "";
 
   emit_event (accessible, ITF_EVENT_OBJECT, name, minor, detail1, detail2,
               DBUS_TYPE_STRING_AS_STRING, text, append_basic);
